@@ -49,8 +49,6 @@ import traceback
 from typing import Any, Dict, List
 
 import lxml.etree
-import notifier
-import notifier.threads
 import psutil
 
 import univention.config_registry
@@ -58,7 +56,7 @@ from univention.lib.admember import connectionFailed, failedADConnect, lookup_ad
 from univention.lib.i18n import Locale, Translation
 from univention.management.console.log import MODULE
 from univention.management.console.modules import Base, UMC_Error
-from univention.management.console.modules.decorators import sanitize, simple_response, threaded
+from univention.management.console.modules.decorators import SimpleThread, sanitize, simple_response, threaded
 from univention.management.console.modules.mixins import ProgressMixin
 from univention.management.console.modules.sanitizers import IntegerSanitizer, PatternSanitizer, StringSanitizer
 
@@ -255,8 +253,8 @@ class Instance(Base, ProgressMixin):
                 self._progressParser.current.critical = True
                 self._finishedResult = True
 
-        thread = notifier.threads.Simple('save', notifier.Callback(_thread, request, self), _finished)
-        thread.run()
+        thread = SimpleThread('save', _thread, _finished)
+        thread.run(request, self)
         self.finished(request.id, None)
 
     @simple_response
@@ -320,8 +318,8 @@ class Instance(Base, ProgressMixin):
                 self._progressParser.current.critical = True
                 self._finishedResult = True
 
-        thread = notifier.threads.Simple('join', notifier.Callback(_thread, self, username, password), _finished)
-        thread.run()
+        thread = SimpleThread('join', _thread, _finished)
+        thread.run(self, username, password)
 
     @threaded
     def check_finished(self, request) -> None:
@@ -656,8 +654,8 @@ class Instance(Base, ProgressMixin):
             self._net_apply_running -= 1
             self.finished(request.id, True)
 
-        thread = notifier.threads.Simple('net_apply', notifier.Callback(_thread, self), _finished)
-        thread.run()
+        thread = SimpleThread('net_apply', _thread, _finished)
+        thread.run(self)
 
     @simple_response
     def net_apply_check_finished(self):
